@@ -2,12 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from syst3m.classes import utils, console, objects, browser, cache
+from syst3m.classes import utils, console, objects, browser, cache, restapi
 from syst3m.classes.system import User, Group, check_user, check_group
+from syst3m.classes import service
 from syst3m.classes.color import color, symbol
 from syst3m.classes import defaults
 from syst3m.classes.env import env
 from syst3m.classes.disks import disks
+from syst3m.classes.restapi import restapi
 #from syst3m.classes.screen import screen
 #from syst3m.classes.keyboard import keyboard
 #from syst3m.classes.mouse import mouse
\ No newline at end of file
