@@ -100,12 +100,10 @@ from r3sponse import ResponseObject
 USER = os.environ.get("USER")
 OWNER = os.environ.get("USER")
 GROUP = "root"
-HOME_BASE = "/home/"
-HOME = f"/home/{os.environ.get('USER')}/"
+HOME = os.environ.get('HOME')
+HOME_BASE = gfp.base(path=HOME)
 MEDIA = f"/media/{os.environ.get('USER')}/"
 if OS in ["macos"]: 
-	HOME_BASE = "/Users/"
-	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
 	GROUP = "wheel"
 
