@@ -14,16 +14,14 @@ vars = r3sponse.ResponseObject({
 	"owner": os.environ.get("USER"),
 	"group": "root",
 	"media": f"/media/{os.environ.get('USER')}",
-	"homes": "/home/",
-	"home": f"/home/{os.environ.get('USER')}/",
+	"homes": gfp.base(path=os.environ.get('HOME')),
+	"home": gfp.clean(os.environ.get('HOME')+"/"),
 	"python3":"python3",
 })
 if vars.os in ["darwin"]:  
 	vars.os = "macos"
 	vars.group = "staff"
 	vars.media = f"/Volumes/"
-	vars.homes = "/Users/"
-	vars.home = f"/Users/{vars.user}/"
 	vars.python3 = f"/usr/bin/python3"
 
 # universal options.
@@ -80,7 +78,9 @@ def alias(
 
 # get source path.
 def source_path(path, back=1):
-	return FilePath(path).base(back=back)
+	source = gfp.clean(path=FilePath(path).base(back=back), remove_double_slash=True)
+	if len(source) > 0 and source[len(source)-1] != "/": source += "/"
+	return source
 
 # get log level.
 def log_level(default=0):
